@@ -226,10 +226,17 @@ kinematicRanges <- function(singleFile,rawdata,curves,mass,smoothingOne,g) {
 		power=c(-maxPower,maxPower)))
 }
 
+
 paint <- function(rawdata, eccon, xmin, xmax, yrange, knRanges, superpose, highlight,
 	startX, startH, smoothing, mass, title, subtitle, draw, showLabels, marShrink, showAxes, legend,
 	Analysis, AnalysisOptions, ExercisePercentBodyWeight 
 	) {
+
+	meanSpeedE = 0
+	meanSpeedC = 0
+	meanPowerE = 0
+	meanPowerC = 0
+
 	#eccons ec and ec-rep is the same here (only show one curve)
 	#receive data as cumulative sum
 	lty=c(1,1,1)
@@ -300,15 +307,12 @@ paint <- function(rawdata, eccon, xmin, xmax, yrange, knRanges, superpose, highl
 		else
 			plot(startX:length(speed$y),speed$y[startX:length(speed$y)],type="l",
 			     xlim=c(1,length(a)),ylim=ylim,xlab="",ylab="",col="darkgreen",lty=2,lwd=3,axes=F)
-		if(showAxes) {
-			axis(4, col=cols[1], lty=lty[1], line=0, lwd=1, padj=-.5)
-			abline(h=0,lty=3,col="black")
-		}
-		#mtext(text=paste("max speed:",round(max(speed$y),3)),side=3,at=which(speed$y == max(speed$y)),cex=.8,col=cols[1])
 	}
 
 	#show extrema values in speed
 	b=extrema(speed$y)
+
+
 	#if(draw & !superpose) 
 	#	segments(x0=b$maxindex,y0=0,x1=b$maxindex,y1=speed$y[b$maxindex],col=cols[1])
 
@@ -318,35 +322,34 @@ paint <- function(rawdata, eccon, xmin, xmax, yrange, knRanges, superpose, highl
 	if(eccon=="c") {
 		concentric=1:length(a)
 	} else {	#"ec", "ec-rep"
-		crossSpeedInMiddle = b$cross[,1]
-		crossDownToUp=0
-		count=1
+		print("EXTREMA")
+		#abline(v=b$maxindex,lty=3,col="yellow");
+		#abline(v=b$minindex,lty=3,col="magenta")
+		print(b)
 
-		#the -2 is to know if speed goes from down to up or vicerversa
-		#we use -2 to know the 2ms before
-		#maybe data has not started, then look what happens 2 ms later
-		for(i in crossSpeedInMiddle) {
-			if(i>2) {
-				if(speed$y[(i-2)]<0) {
-					crossDownToUp[count]=i
-					count=count+1
-				}
-			} else {
-				if(speed$y[(i+2)]>0) {
-					crossDownToUp[count]=i
-					count=count+1
-				}
-			}
-		}
-		eccentric=1:min(crossDownToUp)
-		concentric=max(crossDownToUp):length(a)
+		#In all the extrema minindex values, search which range (row) has the min values,
+		#and in this range search last value
+		print("searchMinSpeedEnd")
+		searchMinSpeedEnd = max(which(speed$y == min(speed$y)))
+		#In all the extrema maxindex values, search which range (row) has the max values,
+		#and in this range search first value
+		print("searchMaxSpeedIni")
+		searchMaxSpeedIni = min(which(speed$y == max(speed$y)))
+		#find the cross between both
+		print("searchMinCross")
+		crossMinRow=which(b$cross[,1] > searchMinSpeedEnd & b$cross[,1] < searchMaxSpeedIni)
+
+		eccentric=1:b$cross[crossMinRow,1]
+		concentric=b$cross[crossMinRow,2]:length(a)
+		isometric=c(b$cross[crossMinRow,1],b$cross[crossMinRow,2])
 		if(draw) {
-			abline(v=min(crossDownToUp),col=cols[1])
-			abline(v=max(crossDownToUp),col=cols[1])
-			mtext(text=min(crossDownToUp),side=1,at=min(crossDownToUp),cex=.8,col=cols[1])
-			mtext(text=max(crossDownToUp),side=1,at=max(crossDownToUp),cex=.8,col=cols[1])
-			mtext(text="eccentric ",side=3,at=min(crossDownToUp),cex=.8,adj=1,col=cols[1],line=.5)
-			mtext(text=" concentric ",side=3,at=max(crossDownToUp),cex=.8,adj=0,col=cols[1],line=.5)
+			abline(v=max(eccentric),col=cols[1])
+			abline(v=min(concentric),col=cols[1])
+			#mtext(text=paste(max(eccentric)," ",sep=""),side=1,at=max(eccentric),adj=1,cex=.8,col=cols[1])
+			#mtext(text=paste(" ",min(concentric),sep=""),side=1,at=min(concentric),adj=0,cex=.8,col=cols[1])
+			mtext(text=mean(isometric),side=1,at=mean(isometric),adj=0.5,cex=.8,col=cols[1])
+			mtext(text="eccentric ",side=3,at=max(eccentric),cex=.8,adj=1,col=cols[1],line=.5)
+			mtext(text=" concentric ",side=3,at=min(concentric),cex=.8,adj=0,col=cols[1],line=.5)
 		}
 	}
 
@@ -365,29 +368,41 @@ paint <- function(rawdata, eccon, xmin, xmax, yrange, knRanges, superpose, highl
 		if(length(which(accel$y[concentric]<=-g)) > 0) {
 			propulsiveEnds = min(which(accel$y[concentric]<=-g))
 		} else {
-			propulsiveEnds=length(concentric)
+			propulsiveEnds=max(concentric)
 		}
 
-		#mean speed propulsive in concentric
-		myMeanSpeed = mean(speed$y[concentric[1]:length(concentric)])
-		myMeanSpeedRight = length(concentric)
-		
-		if(eccon != "c") {
-			propulsiveEnds = propulsiveEnds + concentric[1]
-			myMeanSpeedRight = length(eccentric) + length(concentric)
-		}
-
-		if(AnalysisOptions == "p") {
-			myMeanSpeed = mean(speed$y[concentric[1]:propulsiveEnds])
-			myMeanSpeedRight = propulsiveEnds
-		}
-		arrows(x0=min(concentric),y0=myMeanSpeed,x1=myMeanSpeedRight,y1=myMeanSpeed,col=cols[1],code=3)
-		mtext(paste("mean speed:",round(myMeanSpeed,3)),side=2,
-		      at=myMeanSpeed,line=-1.8,col=cols[1],cex=.8,padj=0)
-
 		ylim=c(-max(abs(range(accel$y))),max(abs(range(accel$y))))	 #put 0 in the middle
-		#if(knRanges[1] != "undefined")
-		#	ylim = knRanges$force
+
+		meanSpeedC = mean(speed$y[min(concentric):max(concentric)])
+		if(AnalysisOptions == "p") {
+			meanSpeedC = mean(speed$y[min(concentric):propulsiveEnds])
+		}
+
+		if(eccon == "c") {
+			arrows(x0=min(concentric),y0=meanSpeedC,x1=propulsiveEnds,y1=meanSpeedC,col=cols[1],code=3)
+		} else {
+			meanSpeedE = mean(speed$y[min(eccentric):max(eccentric)])
+			arrows(x0=min(eccentric),y0=meanSpeedE,x1=max(eccentric),y1=meanSpeedE,col=cols[1],code=3)
+			arrows(x0=min(concentric),y0=meanSpeedC,x1=propulsiveEnds,y1=meanSpeedC,col=cols[1],code=3)
+		}
+
+		
+		#plot the speed axis
+		if(showAxes) {
+			abline(h=0,lty=3,col="black")
+			if(eccon == "c") 
+				axis(4, at=c(min(axTicks(4)),0,max(axTicks(4)),meanSpeedC),
+				     labels=c(min(axTicks(4)),0,max(axTicks(4)),
+					      parse(text=paste("paste(bar(x),'c=',",round(meanSpeedC,1),")"))),
+				     col=cols[1], lty=lty[1], line=0, lwd=1, padj=-.5)
+			else
+				axis(4, at=c(min(axTicks(4)),0,max(axTicks(4)),meanSpeedE,meanSpeedC),
+				     labels=c(min(axTicks(4)),0,max(axTicks(4)),
+					      parse(text=paste("paste(bar(x),'e=',",round(meanSpeedE,1),")")),
+					      parse(text=paste("paste(bar(x),'c=',",round(meanSpeedC,1),")"))),
+				     col=cols[1], lty=lty[1], line=0, lwd=1, padj=-.5)
+		}
+
 		par(new=T)
 		if(highlight==FALSE)
 			plot(startX:length(accel$y),accel$y[startX:length(accel$y)],type="l",
@@ -473,8 +488,34 @@ paint <- function(rawdata, eccon, xmin, xmax, yrange, knRanges, superpose, highl
 		else
 			plot(startX:length(power),power[startX:length(power)],type="l",
 			     xlim=c(1,length(a)),ylim=ylim,xlab="",ylab="",col="darkred",lty=2,lwd=3,axes=F)
-		if(showAxes) 
-			axis(4, col=cols[3], lty=lty[1], line=6, lwd=2, padj=-.5)
+
+
+		meanPowerC = mean(power[min(concentric):max(concentric)])
+		if(AnalysisOptions == "p") {
+			meanPowerC = mean(power[min(concentric):propulsiveEnds])
+		}
+
+		if(eccon == "c") {
+			arrows(x0=min(concentric),y0=meanPowerC,x1=propulsiveEnds,y1=meanPowerC,col=cols[3],code=3)
+		} else {
+			meanPowerE = mean(power[min(eccentric):max(eccentric)])
+			arrows(x0=min(eccentric),y0=meanPowerE,x1=max(eccentric),y1=meanPowerE,col=cols[3],code=3)
+			arrows(x0=min(concentric),y0=meanPowerC,x1=propulsiveEnds,y1=meanPowerC,col=cols[3],code=3)
+		}
+
+		if(showAxes) {
+			if(eccon == "c") 
+				axis(4, at=c(min(axTicks(4)),0,max(axTicks(4)),meanPowerC),
+				     labels=c(min(axTicks(4)),0,max(axTicks(4)),
+					      parse(text=paste("paste(bar(x),'c=',",round(meanPowerC,1),")"))),
+				     col=cols[3], lty=lty[1], line=6, lwd=2, padj=-.5)
+			else
+				axis(4, at=c(min(axTicks(4)),0,max(axTicks(4)),meanPowerE, meanPowerC),
+				     labels=c(min(axTicks(4)),0,max(axTicks(4)),
+					      parse(text=paste("paste(bar(x),'e=',",round(meanPowerE,1),")")),
+					      parse(text=paste("paste(bar(x),'c=',",round(meanPowerC,1),")"))),
+				     col=cols[3], lty=lty[1], line=6, lwd=2, padj=-.5)
+		}
 	}
 
 	#time to arrive to peak power
@@ -485,34 +526,6 @@ paint <- function(rawdata, eccon, xmin, xmax, yrange, knRanges, superpose, highl
 		mtext(text=paste("peak power:",round(max(power),3)),side=3,at=peakPowerT,cex=.8,col=cols[3])
 		mtext(text=peakPowerT,side=1,at=peakPowerT,cex=.8,col=cols[3])
 	}
-	#average power
-
-	meanPowerE = 0
-	if(eccon != "c") 
-		meanPowerE = mean(abs(power[eccentric]))
-	meanPowerC = mean(abs(power[concentric]))
-	if(draw & !superpose & AnalysisOptions != "p") {
-		if(eccon != "c") {
-			arrows(x0=1,y0=meanPowerE,x1=max(eccentric),y1=meanPowerE,col=cols[3],code=3)
-			#text(x=min(eccentric), y=meanPowerE, labels=expression(bar(x)), adj=c(1,0),cex=.8,col=cols[3])
-			text(x=mean(eccentric), y=meanPowerE, labels=paste("mean power:",round(meanPowerE,3)),
-			     adj=c(0.5,0),cex=.8,col=cols[3])
-			#mtext(paste("mean power:",round(meanPowerE,3)),side=4,at=meanPowerE,line=-2,col=cols[3],cex=.8)
-		}
-		arrows(x0=min(concentric),y0=meanPowerC,x1=max(concentric),y1=meanPowerC,col=cols[3],code=3)
-		#text(x=min(concentric), y=meanPowerC, labels=expression(bar(x)), adj=c(1,0),cex=.8,col=cols[3])
-		text(x=mean(concentric), y=meanPowerC, labels=paste("mean power:",round(meanPowerC,3)),
-		     adj=c(0.5,0),cex=.8,col=cols[3])
-		#mtext(paste("mean power:",round(meanPowerC,3)),side=4,at=meanPowerC,line=-2,col=cols[3],cex=.8)
-	}
-		
-	#propulsive phase ends when accel is -9.8
-	if(draw & AnalysisOptions == "p") {
-		#mean power propulsive in concentric
-		meanPowerPropulsive = mean(power[concentric[1]:propulsiveEnds])
-		arrows(x0=min(concentric),y0=meanPowerPropulsive,x1=propulsiveEnds,y1=meanPowerPropulsive,col=cols[3],code=3)
-		mtext(paste("mean power:",round(meanPowerPropulsive,3)),side=4,at=meanPowerPropulsive,line=-2,col=cols[3],cex=.8)
-	}
 
 	#legend, axes and title
 	if(draw) {
@@ -565,7 +578,7 @@ paintPowerPeakPowerBars <- function(singleFile, title, paf, myEccons, Eccon, hei
 			xlab="",ylab="Power (W)", 
 			ylim=c(lowerY,max(powerData)), xpd=FALSE) #ylim, xpd = F,  makes barplot starts high (compare between them)
 	title(main=title,line=-2,outer=T)
-	mtext("Curve\nLoad",side=1,at=0,adj=1,line=1,cex=.9)
+	mtext("Curve\nLoad",side=1,at=1,adj=0,line=1,cex=.9)
 	par(new=T, xpd=T)
 	#on ecS, concentric has high value of time to peak power and eccentric has it very low. Don't draw lines
 	if(Eccon=="ecS")
@@ -722,28 +735,21 @@ find.mfrow <- function(n) {
 }
 
 find.yrange <- function(singleFile, rawdata, curves) {
-	if(singleFile) {
-		a=cumsum(rawdata)
-		y.max = max(a)
-		y.min = min(a)
-		if(y.min < 0) {
-			y.max = y.max + -1*y.min
-			y.min = 0
-		}
-		return (c(y.min,y.max))
-	} else {
-		n=length(curves[,1])
-		y.max = 0
-		y.min = 10000
-		for(i in 1:n) { 
-			y.current = cumsum(rawdata[curves[i,1]:curves[i,2]])
-			if(max(y.current) > y.max)
-				y.max = max(y.current)
-			if(min(y.current) < y.min)
-				y.min = min(y.current)
-		}
-		return (c(y.min,y.max))
+	n=length(curves[,1])
+	y.max = 0
+	y.min = 10000
+	for(i in 1:n) { 
+		y.current = cumsum(rawdata[curves[i,1]:curves[i,2]])
+		if(max(y.current) > y.max)
+			y.max = max(y.current)
+		if(min(y.current) < y.min)
+			y.min = min(y.current)
 	}
+	if(y.min < 0) {
+		y.max = y.max + -1*y.min
+		y.min = 0
+	}
+	return (c(y.min,y.max))
 }
 
 quitIfNoData <- function(n, curves, outputData1) {
