@@ -54,9 +54,9 @@ public class PulseExecute : EventExecute
 
 	//execution
 	public PulseExecute(int personID, string personName, int sessionID, string type, double fixedPulse, int totalPulsesNum,  
-			Chronopic cp, Gtk.TextView event_execute_textview_message, Gtk.Window app, int pDN, bool volumeOn,
+			Chronopic cp, Gtk.Label event_execute_label_message, Gtk.Window app, int pDN, bool volumeOn,
 			//double progressbarLimit, 
-			ExecutingGraphData egd 
+			ExecutingGraphData egd
 			)
 	{
 		this.personID = personID;
@@ -68,7 +68,7 @@ public class PulseExecute : EventExecute
 		
 	
 		this.cp = cp;
-		this.event_execute_textview_message = event_execute_textview_message;
+		this.event_execute_label_message = event_execute_label_message;
 		this.app = app;
 
 		this.pDN = pDN;
