@@ -20,6 +20,7 @@
 
 using System;
 using System.IO; 
+using System.IO.Ports;
 using Gtk;
 using Gdk;
 using Glade;
@@ -36,13 +37,16 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.CheckButton checkbutton_encoder_propulsive;
 
 	[Widget] Gtk.Button button_encoder_capture;
+	[Widget] Gtk.Button button_encoder_capture_csharp;
 	[Widget] Gtk.Button button_encoder_bells;
 	[Widget] Gtk.Button button_encoder_capture_cancel;
+	[Widget] Gtk.Button button_encoder_capture_finish;
 	[Widget] Gtk.Button button_encoder_recalculate;
 	[Widget] Gtk.Button button_encoder_load_signal;
 	[Widget] Gtk.Viewport viewport_image_encoder_capture;
 	[Widget] Gtk.Image image_encoder_bell;
 	[Widget] Gtk.SpinButton spin_encoder_capture_time;
+	[Widget] Gtk.SpinButton spin_encoder_capture_height;
 	[Widget] Gtk.SpinButton spin_encoder_capture_min_height;
 	[Widget] Gtk.Image image_encoder_capture;
 	[Widget] Gtk.TreeView treeview_encoder_curves;
@@ -56,6 +60,9 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Button button_encoder_update_signal;
 	[Widget] Gtk.Button button_encoder_delete_signal;
 	
+	[Widget] Gtk.Notebook notebook_encoder_capture;
+	[Widget] Gtk.DrawingArea encoder_capture_drawingarea;
+	
 	[Widget] Gtk.Box hbox_combo_encoder_exercise;
 	[Widget] Gtk.ComboBox combo_encoder_exercise;
 	[Widget] Gtk.Box hbox_combo_encoder_eccon;
@@ -97,6 +104,8 @@ public partial class ChronoJumpWindow
         Gtk.ListStore encoderListStore;
 
 	Thread encoderThread;
+	
+	Gdk.Pixmap encoder_capture_pixmap = null;
 
 	int image_encoder_width;
 	int image_encoder_height;
@@ -105,42 +114,22 @@ public partial class ChronoJumpWindow
 	private string ecconLast;
 	private string encoderTimeStamp;
 	private string encoderSignalUniqueID;
-	
-	//difference between CAPTURE and RECALCULATE_OR_LOAD is: CAPTURE does a autosave at end
-	enum encoderModes { CAPTURE, RECALCULATE_OR_LOAD, ANALYZE } 
-	enum encoderSensEnum { 
-		NOSESSION, NOPERSON, YESPERSON, PROCESSING, DONENOSIGNAL, DONEYESSIGNAL, SELECTEDCURVE }
-	encoderSensEnum encoderSensEnumStored; //tracks how was sensitive before PROCESSING
- 
+
+	private static int encoderCaptureCountdown;
+	private static Gdk.Point [] encoderCapturePoints;		//stored to be realtime displayed
 	private static bool encoderProcessCancel;
+	private static bool encoderProcessFinish;
 
-	
-	//TODO: auto close capturing window
+	//CAPTURE is the capture from csharp (not from external python)	
+	//difference between CALCULECURVES and RECALCULATE_OR_LOAD is: CALCULECURVES does a autosave at end
+	enum encoderModes { CAPTURE, CALCULECURVES, RECALCULATE_OR_LOAD, ANALYZE } 
+	enum encoderSensEnum { 
+		NOSESSION, NOPERSON, YESPERSON, PROCESSINGCAPTURE, PROCESSINGR, DONENOSIGNAL, DONEYESSIGNAL, SELECTEDCURVE }
+	encoderSensEnum encoderSensEnumStored; //tracks how was sensitive before PROCESSINGCAPTURE or PROCESSINGR
+ 
 
-	//TODO: Put person name in graph (at title,with small separation, or inside graph at topright) (if we click on another person on treeview person, we need to know wich person was last generated graph). Put also exercise name and weight 
-	//TODO: laterality have to be shown on treeviews: signal and curve. also check that is correct in database
-	//TODO: the load (Kg) in graphs has to account the exercice body percent and the extra
-
-	//TODO: put chronopic detection in a generic place. Done But:
-	//TODO: solve the problem of connecting two different chronopics
-	//
 	//TODO:put zoom,unzoom (at side of delete curve)  in capture curves (for every curve)
 	//TODO: treeview on analyze (doing in separated window)
-	
-	//to analyze: user has to select: session, athlete, exercise, 
-	//TODO: single curve, and side, checkbox to show1 param, 2 or three
-	//TODO: powerbars with checkbox to show1 param, 2 or three
-	//TODO: on capture (quasi-realtime), show powerbars or curves or both
-	//
-	//TODO: if a signal is loaded, exercise has to be updated on combo. (use exerciseID in database)
-	//
-	//TODO: do the graphical capturing with pygame
-	//
-	//TODO: allow gui/generic.cs to select rows on treeview to be deleted
-	//
-	//TODO: calling to R should give feedback during the process
-	//
-	//TODO: fix problem that on saving maybe dirs are not created
 	//
 	//TODO: on session load, show encoder stuff
 	//
@@ -166,8 +155,7 @@ public partial class ChronoJumpWindow
 		treeview_encoder_curves.CursorChanged += on_treeview_encoder_curves_cursor_changed; 
 		createEncoderCombos();
 	}
-
-	//TODO: garantir path windows	
+	
 	void on_button_encoder_capture_clicked (object o, EventArgs args) 
 	{
 		if(chronopicWin.GetEncoderPort() == Util.GetDefaultPort()) {
@@ -236,16 +224,58 @@ public partial class ChronoJumpWindow
 				"",					//no graph ouptut
 				Util.GetEncoderDataTempFileName(), "", ep);				
 
-		//title to sen to python software has to be without spaces
-		Util.RunEncoderCapture( 
-				Util.ChangeSpaceForUnderscore(currentPerson.Name) + "----" + 
-				Util.ChangeSpaceForUnderscore(exerciseNameShown) + "----(" + findMass(true) + "Kg)",
-				es, chronopicWin.GetEncoderPort());
+		if (o == (object) button_encoder_capture) {
+			//title to sen to python software has to be without spaces
+			Util.RunEncoderCapturePython( 
+					Util.ChangeSpaceForUnderscore(currentPerson.Name) + "----" + 
+					Util.ChangeSpaceForUnderscore(exerciseNameShown) + "----(" + findMass(true) + "Kg)",
+					es, chronopicWin.GetEncoderPort());
 
+			calculeCurves();
+		}
+		else if (o == (object) button_encoder_capture_csharp) {
+			if(notebook_encoder_capture.CurrentPage == 1)
+				notebook_encoder_capture.PrevPage();
+
+			Log.WriteLine("AAAAAAAAAAAAAAA");
+			encoderThreadStart(encoderModes.CAPTURE);
+
+			Log.WriteLine("ZZZZZZZZZZZZZZZ");
+		}
+	}
+
+	void calculeCurves() {
 		encoderTimeStamp = UtilDate.ToFile(DateTime.Now);
 		encoderSignalUniqueID = "-1"; //mark to know that there's no ID for this until it's saved on database
 
-		encoderThreadStart(encoderModes.CAPTURE);
+		encoderThreadStart(encoderModes.CALCULECURVES);
+	}
+	
+	void on_button_encoder_capture_help_clicked (object o, EventArgs args)
+	{
+		new DialogMessage(Constants.MessageTypes.INFO, 
+				"<b>ENGLISH:</b> Since version 1.3.4 there are two methods of capture:\n\n" +
+				"- <b>External</b>: Capture happens in a new window\n" + 
+				"  Advantages: Has realtime graphs and lots of features\n" + 
+				"  Disavantages: Open new window is slow and there are problems on some computers\n\n" +
+				"- <b>Safe</b>: Capture happens in this window\n" +
+				"  Advantages: Fast and without problems\n" + 
+				"  Disavantages: Currently at realtime only plots a simple graph\n\n" +
+				"Conclusion: In next versions 'Safe' mode will be the only one\n" +
+				"Now it lacks features like realtime statistics and graphs\n" +
+				"<b>After</b> capturing, both methods show the same results" +
+				"\n\n" +
+				"<b>CASTELLANO:</b> A partir de la versión 1.3.4 hay dos métodos de capturar:\n\n" +
+				"- <b>External (externo)</b>: Se captura en una nueva ventana\n" + 
+				"  Ventajas: Tiene gráficos en tiempo real y muchas posibilidades\n" + 
+				"  Desventajas: Abrir una nueva ventana es lento y da problemas en algunos equipos\n\n" +
+				"- <b>Safe (seguro)</b>: Se captura en esta ventana\n" +
+				"  Ventajas: Rápido y no da problemas\n" + 
+				"  Desventajas: Actualmente en tiempo real sólo muestra un gráfico sencillo\n\n" +
+				"Conclusión: En las siguientes versiones el modo 'Seguro' será el único\n" +
+				"En este momento carece de las ventajas del modo externo\n" +
+				"<b>Después</b> de la captura, ambos métodos muestran los mismos resultados"
+				);
 	}
 		
 	void on_button_encoder_cancel_clicked (object o, EventArgs args) 
@@ -253,6 +283,11 @@ public partial class ChronoJumpWindow
 		encoderProcessCancel = true;
 	}
 
+	void on_button_encoder_capture_finish_clicked (object o, EventArgs args) 
+	{
+		encoderProcessFinish = true;
+	}
+
 	void on_button_encoder_recalculate_clicked (object o, EventArgs args) 
 	{
 		if (File.Exists(Util.GetEncoderDataTempFileName()))
@@ -300,6 +335,7 @@ public partial class ChronoJumpWindow
 
 	//this is called by non gtk thread. Don't do gtk stuff here
 	//I suppose reading gtk is ok, changing will be the problem
+	//called on calculatecurves, recalculate and load
 	private void encoderCreateCurvesGraphR() 
 	{
 		string analysisOptions = "-";
@@ -387,7 +423,6 @@ public partial class ChronoJumpWindow
 		//genericWin.DestroyOnAccept=true;
 		//here is comented because we are going to read the checkboxes
 
-		genericWin.SetButtonAcceptLabel(Catalog.GetString("Close"));
 		genericWin.ShowNow();
 	}
 	
@@ -452,6 +487,7 @@ public partial class ChronoJumpWindow
 					currentPerson.Name), Constants.GenericWindowShow.TREEVIEW);
 
 		genericWin.SetTreeview(columnsString, false, dataPrint);
+		genericWin.ShowButtonCancel(true);
 		genericWin.SetButtonAcceptLabel(Catalog.GetString("Load"));
 		genericWin.SetButtonAcceptSensitive(false);
 		genericWin.Button_accept.Clicked += new EventHandler(on_encoder_load_signal_accepted);
@@ -470,9 +506,9 @@ public partial class ChronoJumpWindow
 
 		foreach(EncoderSQL es in data) {	//it will run only one time
 			Util.CopyEncoderDataToTemp(es.url, es.filename);
-			UtilGtk.ComboMakeActive(combo_encoder_exercise, es.exerciseName);
-			UtilGtk.ComboMakeActive(combo_encoder_eccon, es.ecconLong);
-			UtilGtk.ComboMakeActive(combo_encoder_laterality, es.laterality);
+			combo_encoder_exercise.Active = UtilGtk.ComboMakeActive(combo_encoder_exercise, es.exerciseName);
+			combo_encoder_eccon.Active = UtilGtk.ComboMakeActive(combo_encoder_eccon, es.ecconLong);
+			combo_encoder_laterality.Active = UtilGtk.ComboMakeActive(combo_encoder_laterality, es.laterality);
 			spin_encoder_extra_weight.Value = Convert.ToInt32(es.extraWeight);
 
 			spin_encoder_capture_min_height.Value = es.minHeight;
@@ -519,7 +555,9 @@ public partial class ChronoJumpWindow
 		EncoderStruct encoderStruct = new EncoderStruct(
 				dataFileName, 
 				Util.GetEncoderGraphTempFileName(),
-				selectedFileName, "NULL", ep);
+				selectedFileName, 
+				Util.GetEncoderStatusTempFileName(),
+				ep);
 
 		Util.RunEncoderGraph(
 				Util.ChangeSpaceForUnderscore(currentPerson.Name) + "-" + 
@@ -609,7 +647,7 @@ public partial class ChronoJumpWindow
 		EncoderSQL eSQL = (EncoderSQL) SqliteEncoder.Select(
 				false, Convert.ToInt32(encoderSignalUniqueID), 0, 0, "")[0];
 		//remove the file
-		bool deletedOk = Util.FileDelete(eSQL.GetFullURL());
+		bool deletedOk = Util.FileDelete(eSQL.GetFullURL(false));	//don't convertPathToR
 		if(deletedOk) {
 			Sqlite.Delete(Constants.EncoderTable, Convert.ToInt32(encoderSignalUniqueID));
 			encoderSignalUniqueID = "-1";
@@ -660,7 +698,8 @@ public partial class ChronoJumpWindow
 				encoder_pulsebar_capture.Text = encoderSaveSignalOrCurve("curve", selectedID);
 			} else if(button == button_encoder_save_all_curves) 
 				for(int i=1; i <= UtilGtk.CountRows(encoderListStore); i++)
-					encoder_pulsebar_capture.Text = encoderSaveSignalOrCurve("allCurves", i);
+					if(! Util.IsEven(i)) //use only uneven (spanish: "impar") values
+						encoder_pulsebar_capture.Text = encoderSaveSignalOrCurve("allCurves", i);
 
 			ArrayList data = SqliteEncoder.Select(false, -1, 
 					currentPerson.UniqueID, currentSession.UniqueID, "curve");
@@ -828,6 +867,114 @@ public partial class ChronoJumpWindow
 		encoderThreadStart(encoderModes.ANALYZE);
 	}
 	
+	//this is called by non gtk thread. Don't do gtk stuff here
+	//I suppose reading gtk is ok, changing will be the problem
+	private void captureCsharp () 
+	{
+		Log.WriteLine("EEEEEEEEEEEEEEE");
+		string exerciseNameShown = UtilGtk.ComboGetActive(combo_encoder_exercise);
+		bool capturedOk = runEncoderCaptureCsharp( 
+				Util.ChangeSpaceForUnderscore(currentPerson.Name) + "----" + 
+				Util.ChangeSpaceForUnderscore(exerciseNameShown) + "----(" + findMass(true) + "Kg)",
+				//es, 
+				(int) spin_encoder_capture_time.Value, 
+				Util.GetEncoderDataTempFileName(),
+				chronopicWin.GetEncoderPort());
+		Log.WriteLine("FFFFFFFFFFFFFFF");
+	
+		//wait to ensure capture thread has ended
+		Thread.Sleep(500);	
+
+		//will start calcule curves thread
+		if(capturedOk)
+			calculeCurves();
+
+		Log.WriteLine("F22222222222222");
+	}
+	
+	//private bool runEncoderCaptureCsharp(string title, EncoderStruct es, string port) 
+	private bool runEncoderCaptureCsharp(string title, int time, string outputData1, string port) 
+	{
+		int width=encoder_capture_drawingarea.Allocation.Width;
+		int height=encoder_capture_drawingarea.Allocation.Height;
+		//int yrange = height;
+		double realHeight = 1000 * 2 * spin_encoder_capture_height.Value;
+		
+		Log.WriteLine("00a");
+		SerialPort sp = new SerialPort(port);
+		Log.WriteLine("00b");
+		sp.BaudRate = 115200;
+		Log.WriteLine("00c");
+		sp.Open();
+		Log.WriteLine("00d");
+			
+		encoderCaptureCountdown = time;
+		//int recordingTime = es.Ep.Time * 1000;
+		int recordingTime = time * 1000;
+		
+		int b;
+		int sum = 0;
+		string dataString = "";
+		string sep = "";
+		
+		int i =-20; //delete first records because there's encoder bug
+		int msCount = 0;
+		//int maxy = 1;
+		//int miny = 1;
+		encoderCapturePoints = new Gdk.Point[recordingTime];
+		do {
+			b = sp.ReadByte();
+			if(b > 128)
+				b = b-256;
+			i=i+1;
+			if(i >= 0) {
+				//Log.Write(sep + b.ToString());
+
+				sum += b;
+
+				/*
+				if(sum > maxy)
+					maxy = sum;
+				if(sum < miny)
+					miny = sum;
+				yrange = maxy + System.Math.Abs(miny);
+				encoderCapturePointsRange = yrange;
+				*/
+
+				encoderCapturePoints[i] = new Gdk.Point(
+						Convert.ToInt32(width*i/recordingTime),
+						//Convert.ToInt32( (height/2) - ( sum * height / 2000) ) //2m detection
+						Convert.ToInt32( (height/2) - ( sum * height / realHeight) )
+						);
+
+				dataString += sep + b.ToString();
+				sep = ", ";
+			
+				msCount ++;
+				if(msCount >= 1000) {
+					encoderCaptureCountdown --;
+					msCount = 1;
+				}
+			}
+		} while (i < (recordingTime -1) && ! encoderProcessCancel && ! encoderProcessFinish);
+		//Log.WriteLine(sum.ToString());
+
+		Log.WriteLine("00e");
+		sp.Close();
+		Log.WriteLine("00f");
+
+		if(encoderProcessCancel)
+			return false;
+		
+		//TextWriter writer = File.CreateText(es.OutputData1);
+		TextWriter writer = File.CreateText(outputData1);
+		writer.Write(dataString);
+		writer.Flush();
+		((IDisposable)writer).Dispose();
+
+		return true;
+	}
+
 	//this is called by non gtk thread. Don't do gtk stuff here
 	//I suppose reading gtk is ok, changing will be the problem
 	private void analyze () 
@@ -914,7 +1061,7 @@ public partial class ChronoJumpWindow
 				writer.WriteLine(eSQL.future1 + "," + ex.name + "," + 
 						Util.ConvertToPoint(mass).ToString() + "," + 
 						Util.ConvertToPoint(eSQL.smooth) + "," + eSQL.GetDate(true) + "," + 
-						eSQL.GetFullURL() + "," +
+						eSQL.GetFullURL(true) + "," +	//convertPathToR
 						eSQL.eccon	//this is the eccon of every curve
 						);
 			}
@@ -1278,7 +1425,6 @@ public partial class ChronoJumpWindow
 		genericWin.LabelEntry2 = Catalog.GetString("Resistance");
 		genericWin.LabelEntry3 = Catalog.GetString("Description");
 		genericWin.ShowButtonCancel(false);
-		genericWin.SetButtonAcceptLabel(Catalog.GetString("Close"));
 		genericWin.ShowNow();
 	}
 
@@ -1496,7 +1642,7 @@ public partial class ChronoJumpWindow
 				String.Format(UtilGtk.TVNumPrint(curve.N,1,0),Convert.ToInt32(curve.N));
 		else {
 			string phase = "e";
-			bool isEven = (Convert.ToInt32(curve.N) % 2 == 0); //check if it's even (in spanish "par")
+			bool isEven = Util.IsEven(Convert.ToInt32(curve.N));
 			if(isEven)
 				phase = "c";
 				
@@ -1764,7 +1910,8 @@ public partial class ChronoJumpWindow
 
 	private void encoderButtonsSensitive(encoderSensEnum option) {
 		//columns
-		//c0 button_encoder_capture, button_encoder_bells
+		//c0 button_encoder_capture, button_encoder_capture_csharp, 
+		//	button_encoder_bells, spin_encoder_capture_time, spin_encoder_capture_height
 		//c1 button_encoder_recalculate
 		//c2 button_encoder_load_signal
 		//c3 button_encoder_save_all_curves, button_encoder_export_all_curves,
@@ -1774,7 +1921,8 @@ public partial class ChronoJumpWindow
 		//c4 button_encoder_delete_curve , button_encoder_save_curve, entry_encoder_curve_comment
 		//c5 button_encoder_analyze
 		//c6 button_encoder_analyze_data_show_user_curves
-		//c7 button_cancel (on capture and analyze)
+		//c7 button_encoder_capture_cancel (on capture and analyze)
+		//c8 button_encoder_capture_finish (only on capture)
 
 		//other dependencies
 		//c5 True needs 
@@ -1782,17 +1930,18 @@ public partial class ChronoJumpWindow
 		//	(! radiobutton_encoder_analyze_data_current_signal.Active && user has curves))
 		//c6 True needs ! radiobutton_encoder_analyze_data_current_signal.Active
 
-		if(option != encoderSensEnum.PROCESSING)
+		if(option != encoderSensEnum.PROCESSINGCAPTURE && option != encoderSensEnum.PROCESSINGR)
 			encoderSensEnumStored = option;
 		
-		//columns		 0  1  2  3  4  5  6  7
-		int [] noSession = 	{0, 0, 0, 0, 0, 0, 0, 0};
-		int [] noPerson = 	{0, 0, 0, 0, 0, 0, 0, 0};
-		int [] yesPerson = 	{1, 0, 1, 0, 0, 1, 1, 0};
-		int [] processing = 	{0, 0, 0, 0, 0, 0, 0, 1};
-		int [] doneNoSignal = 	{1, 0, 1, 0, 0, 1, 1, 0};
-		int [] doneYesSignal = 	{1, 1, 1, 1, 0, 1, 1, 0};
-		int [] selectedCurve = 	{1, 1, 1, 1, 1, 1, 1, 0};
+		//columns		 	 0  1  2  3  4  5  6  7  8
+		int [] noSession = 		{0, 0, 0, 0, 0, 0, 0, 0, 0};
+		int [] noPerson = 		{0, 0, 0, 0, 0, 0, 0, 0, 0};
+		int [] yesPerson = 		{1, 0, 1, 0, 0, 1, 1, 0, 0};
+		int [] processingCapture = 	{0, 0, 0, 0, 0, 0, 0, 1, 1};
+		int [] processingR = 		{0, 0, 0, 0, 0, 0, 0, 1, 0};
+		int [] doneNoSignal = 		{1, 0, 1, 0, 0, 1, 1, 0, 0};
+		int [] doneYesSignal = 		{1, 1, 1, 1, 0, 1, 1, 0, 0};
+		int [] selectedCurve = 		{1, 1, 1, 1, 1, 1, 1, 0, 0};
 		int [] table = new int[7];
 
 		switch(option) {
@@ -1805,8 +1954,11 @@ public partial class ChronoJumpWindow
 			case encoderSensEnum.YESPERSON:
 				table = yesPerson;
 				break;
-			case encoderSensEnum.PROCESSING:
-				table = processing;
+			case encoderSensEnum.PROCESSINGCAPTURE:
+				table = processingCapture;
+				break;
+			case encoderSensEnum.PROCESSINGR:
+				table = processingR;
 				break;
 			case encoderSensEnum.DONENOSIGNAL:
 				table = doneNoSignal;
@@ -1820,7 +1972,11 @@ public partial class ChronoJumpWindow
 		}
 
 		button_encoder_capture.Sensitive = Util.IntToBool(table[0]);
+		button_encoder_capture_csharp.Sensitive = Util.IntToBool(table[0]);
 		button_encoder_bells.Sensitive = Util.IntToBool(table[0]);
+		spin_encoder_capture_time.Sensitive = Util.IntToBool(table[0]);
+		spin_encoder_capture_height.Sensitive = Util.IntToBool(table[0]);
+
 		button_encoder_recalculate.Sensitive = Util.IntToBool(table[1]);
 		button_encoder_load_signal.Sensitive = Util.IntToBool(table[2]);
 		
@@ -1854,15 +2010,113 @@ public partial class ChronoJumpWindow
 		
 		button_encoder_capture_cancel.Sensitive = Util.IntToBool(table[7]);
 		button_encoder_analyze_cancel.Sensitive = Util.IntToBool(table[7]);
+		
+		button_encoder_capture_finish.Sensitive = Util.IntToBool(table[8]);
 	}
 
 	/* end of sensitivity stuff */	
+	
+	/* update capture graph */	
+	
+	private void updateEncoderCaptureGraph() {
+		if(encoderCapturePoints != null) {
+Log.WriteLine("RRR");	
+			UtilGtk.ErasePaint(encoder_capture_drawingarea, encoder_capture_pixmap);
+Log.WriteLine("RRR2");	
+		
+			pen_azul = new Gdk.GC(encoder_capture_drawingarea.GdkWindow);
+			pen_azul.Foreground = UtilGtk.BLUE_PLOTS;
+					
+Log.WriteLine("RRR3");	
+
+/*
+			int height=encoder_capture_drawingarea.Allocation.Height;
+			for(int i=0; i < encoderCapturePoints.Length ; i ++)
+				encoderCapturePoints[i].Y = Convert.ToInt32(
+						encoderCapturePoints[i].Y * height / encoderCapturePointsRange);
+*/
+
+
+			//also can be optimized to do not erase window every time and only add points since last time
+			encoder_capture_pixmap.DrawPoints(pen_azul, encoderCapturePoints);
+
+			/*
+			Gdk.Point [] myPoints = new Gdk.Point[3];
+			myPoints[0] = new Gdk.Point(20,20);
+			myPoints[1] = new Gdk.Point(40,20);
+			myPoints[2] = new Gdk.Point(100,20);
+			encoder_capture_pixmap.DrawPoints(pen_azul, myPoints);
+			*/
+Log.WriteLine("RRR4");	
+		}
+	}
+	
+	int encoder_capture_allocationXOld;
+	bool encoder_capture_sizeChanged;
+	public void on_encoder_capture_drawingarea_configure_event(object o, ConfigureEventArgs args)
+	{
+		Gdk.EventConfigure ev = args.Event;
+		Gdk.Window window = ev.Window;
+
+		Gdk.Rectangle allocation = encoder_capture_drawingarea.Allocation;
+		
+		if(encoder_capture_pixmap == null || encoder_capture_sizeChanged || 
+				allocation.Width != encoder_capture_allocationXOld) {
+			encoder_capture_pixmap = new Gdk.Pixmap (window, allocation.Width, allocation.Height, -1);
+		
+			UtilGtk.ErasePaint(encoder_capture_drawingarea, encoder_capture_pixmap);
 			
+			encoder_capture_sizeChanged = false;
+		}
+
+		encoder_capture_allocationXOld = allocation.Width;
+	}
+	
+	public void on_encoder_capture_drawingarea_expose_event(object o, ExposeEventArgs args)
+	{
+		/* in some mono installations, configure_event is not called, but expose_event yes. 
+		 * Do here the initialization
+		 */
+		
+		Gdk.Rectangle allocation = encoder_capture_drawingarea.Allocation;
+		if(encoder_capture_pixmap == null || encoder_capture_sizeChanged || 
+				allocation.Width != encoder_capture_allocationXOld) {
+			encoder_capture_pixmap = new Gdk.Pixmap (encoder_capture_drawingarea.GdkWindow, allocation.Width, allocation.Height, -1);
+			UtilGtk.ErasePaint(encoder_capture_drawingarea, encoder_capture_pixmap);
+
+			encoder_capture_sizeChanged = false;
+		}
+
+		Gdk.Rectangle area = args.Event.Area;
+
+		//sometimes this is called when pait is finished
+		//don't let this erase win
+		if(encoder_capture_pixmap != null) {
+			args.Event.Window.DrawDrawable(encoder_capture_drawingarea.Style.WhiteGC, encoder_capture_pixmap,
+				area.X, area.Y,
+				area.X, area.Y,
+				area.Width, area.Height);
+		}
+		
+		encoder_capture_allocationXOld = allocation.Width;
+	}
+
+
+	/* end of update capture graph */	
 	
 	/* thread stuff */
 
 	private void encoderThreadStart(encoderModes mode) {
-		if(mode == encoderModes.CAPTURE || mode == encoderModes.RECALCULATE_OR_LOAD) {
+		encoderProcessCancel = false;
+		encoderProcessFinish = false;
+		if(mode == encoderModes.CAPTURE) {
+			//encoder_pulsebar_capture.Text = Catalog.GetString("Please, wait.");
+			Log.WriteLine("CCCCCCCCCCCCCCC");
+			encoderThread = new Thread(new ThreadStart(captureCsharp));
+			GLib.Idle.Add (new GLib.IdleHandler (pulseGTKEncoderCapture));
+			Log.WriteLine("DDDDDDDDDDDDDDD");
+			encoderButtonsSensitive(encoderSensEnum.PROCESSINGCAPTURE);
+		} else if(mode == encoderModes.CALCULECURVES || mode == encoderModes.RECALCULATE_OR_LOAD) {
 			//image is inside (is smaller than) viewport
 			image_encoder_width = UtilGtk.WidgetWidth(viewport_image_encoder_capture)-5; 
 			image_encoder_height = UtilGtk.WidgetHeight(viewport_image_encoder_capture)-5;
@@ -1870,37 +2124,54 @@ public partial class ChronoJumpWindow
 //			encoder_pulsebar_capture.Text = Catalog.GetString("Please, wait.");
 			treeview_encoder_curves.Sensitive = false;
 			encoderThread = new Thread(new ThreadStart(encoderCreateCurvesGraphR));
-			if(mode == encoderModes.CAPTURE)
-				GLib.Idle.Add (new GLib.IdleHandler (pulseGTKEncoderCapture));
+			if(mode == encoderModes.CALCULECURVES)
+				GLib.Idle.Add (new GLib.IdleHandler (pulseGTKEncoderCalculeCurves));
 			else // mode == encoderModes.RECALCULATE_OR_LOAD
 				GLib.Idle.Add (new GLib.IdleHandler (pulseGTKEncoderRecalculateOrLoad));
+			encoderButtonsSensitive(encoderSensEnum.PROCESSINGR);
 		} else { //encoderModes.ANALYZE
 			//the -3 is because image is inside (is smaller than) viewport
 			image_encoder_width = UtilGtk.WidgetWidth(viewport_image_encoder_analyze)-5; 
 			image_encoder_height = UtilGtk.WidgetHeight(viewport_image_encoder_analyze)-5;
 
 			encoder_pulsebar_analyze.Text = Catalog.GetString("Please, wait.");
-
 		
 			encoderThread = new Thread(new ThreadStart(analyze));
 			GLib.Idle.Add (new GLib.IdleHandler (pulseGTKEncoderAnalyze));
+			encoderButtonsSensitive(encoderSensEnum.PROCESSINGR);
 		}
-		encoderButtonsSensitive(encoderSensEnum.PROCESSING);
 		encoderThread.Start(); 
 	}
-	
+
+	//this is the only who was finish	
 	private bool pulseGTKEncoderCapture ()
+	{
+		Log.WriteLine("PPPPPPPPP");
+		if(! encoderThread.IsAlive || encoderProcessCancel || encoderProcessFinish) {
+			finishPulsebar(encoderModes.CAPTURE);
+			Log.Write("dying");
+			return false;
+		}
+		updatePulsebar(encoderModes.CAPTURE); //activity on pulsebar
+		updateEncoderCaptureGraph();
+
+		Thread.Sleep (50);
+		Log.Write(encoderThread.ThreadState.ToString());
+		return true;
+	}
+	
+	private bool pulseGTKEncoderCalculeCurves ()
 	{
 		if(! encoderThread.IsAlive || encoderProcessCancel) {
 			if(encoderProcessCancel){
 				Util.CancelRScript = true;
 			}
 
-			finishPulsebar(encoderModes.CAPTURE);
+			finishPulsebar(encoderModes.CALCULECURVES);
 			Log.Write("dying");
 			return false;
 		}
-		updatePulsebar(encoderModes.CAPTURE); //activity on pulsebar
+		updatePulsebar(encoderModes.CALCULECURVES); //activity on pulsebar
 		Thread.Sleep (50);
 		Log.Write(encoderThread.ThreadState.ToString());
 		return true;
@@ -1917,7 +2188,7 @@ public partial class ChronoJumpWindow
 			Log.Write("dying");
 			return false;
 		}
-		updatePulsebar(encoderModes.CAPTURE); //activity on pulsebar
+		updatePulsebar(encoderModes.CALCULECURVES); //activity on pulsebar
 		Thread.Sleep (50);
 		Log.Write(encoderThread.ThreadState.ToString());
 		return true;
@@ -1941,25 +2212,73 @@ public partial class ChronoJumpWindow
 	}
 	
 	private void updatePulsebar (encoderModes mode) {
-		string contents = Catalog.GetString("Please, wait.");
-		if(Util.FileExists(Util.GetEncoderStatusTempFileName()))
-			contents = Util.ReadFile(Util.GetEncoderStatusTempFileName(), true);
+		if(mode == encoderModes.CAPTURE) {
+			int selectedTime = (int) spin_encoder_capture_time.Value;
+			encoder_pulsebar_capture.Fraction = Util.DivideSafeFraction(
+					(selectedTime - encoderCaptureCountdown), selectedTime);
+			encoder_pulsebar_capture.Text = encoderCaptureCountdown + " s";
+			return;
+		}
 
-		if(mode == encoderModes.CAPTURE || mode == encoderModes.RECALCULATE_OR_LOAD) {
-			encoder_pulsebar_capture.Pulse();
-			encoder_pulsebar_capture.Text = contents;
+		string contents = Catalog.GetString("Please, wait.");
+		double fraction = -1;
+		if(Util.FileExists(Util.GetEncoderStatusTempFileName())) {
+			contents = Util.ReadFile(Util.GetEncoderStatusTempFileName(), true);
+			//contents is:
+			//(1/5) Starting R
+			//(5/5) R tasks done
+			
+			//-48: ascii 0 char
+			if(System.Char.IsDigit(contents[1]) && System.Char.IsDigit(contents[3]))
+			       fraction = Util.DivideSafeFraction(
+					Convert.ToInt32(contents[1]-48), Convert.ToInt32(contents[3]-48) );
+		}
+
+		if(mode == encoderModes.CALCULECURVES || mode == encoderModes.RECALCULATE_OR_LOAD) {
+			if(fraction == -1) {
+				encoder_pulsebar_capture.Pulse();
+				encoder_pulsebar_capture.Text = contents;
+			} else {
+				encoder_pulsebar_capture.Fraction = fraction;
+				encoder_pulsebar_capture.Text = contents.Substring(6);
+			}
 		} else {
-			encoder_pulsebar_analyze.Pulse();
-			encoder_pulsebar_analyze.Text = contents;
+			if(fraction == -1) {
+				encoder_pulsebar_analyze.Pulse();
+				encoder_pulsebar_analyze.Text = contents;
+			} else {
+				encoder_pulsebar_analyze.Fraction = fraction;
+				encoder_pulsebar_analyze.Text = contents.Substring(6);
+			}
+			
 		}
 	}
 	
 	private void finishPulsebar(encoderModes mode) {
-		if(mode == encoderModes.CAPTURE || mode == encoderModes.RECALCULATE_OR_LOAD) {
+		if(
+				mode == encoderModes.CAPTURE || 
+				mode == encoderModes.CALCULECURVES || 
+				mode == encoderModes.RECALCULATE_OR_LOAD )
+		{
+			Log.WriteLine("ffffffinishPulsebarrrrr");
 			if(encoderProcessCancel) {
-				encoderProcessCancel = false;
-				encoderButtonsSensitive(encoderSensEnum.DONEYESSIGNAL);
+				//encoderButtonsSensitive(encoderSensEnum.DONEYESSIGNAL);
+				encoderButtonsSensitive(encoderSensEnumStored);
 				encoder_pulsebar_capture.Text = Catalog.GetString("Cancelled");
+				if(notebook_encoder_capture.CurrentPage == 0 )
+					notebook_encoder_capture.NextPage();
+			}
+
+			if(
+				( mode == encoderModes.CALCULECURVES || 
+				  mode == encoderModes.RECALCULATE_OR_LOAD ) &&
+				notebook_encoder_capture.CurrentPage == 0 )
+					notebook_encoder_capture.NextPage();
+
+			if(mode == encoderModes.CAPTURE && encoderProcessFinish) {
+				//encoderButtonsSensitive(encoderSensEnum.DONEYESSIGNAL);
+				encoderButtonsSensitive(encoderSensEnumStored);
+				encoder_pulsebar_capture.Text = Catalog.GetString("Finished");
 			} else {
 				Pixbuf pixbuf = new Pixbuf (Util.GetEncoderGraphTempFileName()); //from a file
 				image_encoder_capture.Pixbuf = pixbuf;
@@ -1967,7 +2286,7 @@ public partial class ChronoJumpWindow
 				image_encoder_capture.Sensitive = true;
 		
 				//autosave signal (but not in recalculate or load)
-				if(mode == encoderModes.CAPTURE)
+				if(mode == encoderModes.CALCULECURVES)
 					encoder_pulsebar_capture.Text = encoderSaveSignalOrCurve("signal", 0);
 				else
 					encoder_pulsebar_capture.Text = "";
@@ -1977,7 +2296,6 @@ public partial class ChronoJumpWindow
 
 		} else { //ANALYZE
 			if(encoderProcessCancel) {
-				encoderProcessCancel = false;
 				encoder_pulsebar_analyze.Text = Catalog.GetString("Cancelled");
 			} else {
 				//TODO pensar en si s'ha de fer 1er amb mida petita i despres amb gran (en el zoom),
@@ -1999,4 +2317,3 @@ public partial class ChronoJumpWindow
 	/* end of thread stuff */
 	
 }	
-
